==> cli-3.29.0.tar.gz: cli-3.29.0/pkg/flink/config/sql_keywords.go <==
package config

import (
	"github.com/confluentinc/cli/v3/pkg/types"
)

// These are all Flink SQL reserved keywords extracted from https://nightlies.apache.org/flink/flink-docs-release-1.16/docs/dev/table/sql/overview/

var SQLKeywords = types.NewSet(
	"USE",
	"SHOW",
	"LOAD",
	"A",
	"ABS",
	"ABSOLUTE",
	"ACTION",
	"ADA",
	"ADD",
	"ADMIN",
	"AFTER",
	"ALL",
	"ALLOCATE",
	"ALLOW",
	"ALTER",
	"ALWAYS",
	"AND",
	"ANALYZE",
	"ANY",
	"ARE",
	"ARRAY",
	"AS",
	"ASC",
	"ASENSITIVE",
	"ASSERTION",
	"ASSIGNMENT",
	"ASYMMETRIC",
	"AT",
	"ATOMIC",
	"ATTRIBUTE",
	"ATTRIBUTES",
	"AUTHORIZATION",
	"AVG",
	"BEFORE",
	"BEGIN",
	"BERNOULLI",
	"BETWEEN",
	"BIGINT",
	"BINARY",
	"BIT",
	"BLOB",
	"BOOLEAN",
	"BOTH",
	"BREADTH",
	"BY",
	"BYTES",
	"C",
	"CALL",
	"CALLED",
	"CARDINALITY",
	"CASCADE",
	"CASCADED",
	"CASE",
	"CAST",
	"CATALOG",
	"CATALOG_NAME",
	"CEIL",
	"CEILING",
	"CENTURY",
	"CHAIN",
	"CHAR",
	"CHARACTER",
	"CHARACTERISTICS",
	"CHARACTERS",
	"CHARACTER_LENGTH",
	"CHARACTER_SET_CATALOG",
	"CHARACTER_SET_NAME",
	"CHARACTER_SET_SCHEMA",
	"CHAR_LENGTH",
	"CHECK",
	"CLASS_ORIGIN",
	"CLOB",
	"CLOSE",
	"COALESCE",
	"COBOL",
	"COLLATE",
	"COLLATION",
	"COLLATION_CATALOG",
	"COLLATION_NAME",
	"COLLATION_SCHEMA",
	"COLLECT",
	"COLUMN",
	"COLUMNS",
	"COLUMN_NAME",
	"COMMAND_FUNCTION",
	"COMMAND_FUNCTION_CODE",
	"COMMIT",
	"COMMITTED",
	"CONDITION",
	"CONDITION_NUMBER",
	"CONNECT",
	"CONNECTION",
	"CONNECTION_NAME",
	"CONSTRAINT",
	"CONSTRAINTS",
	"CONSTRAINT_CATALOG",
	"CONSTRAINT_NAME",
	"CONSTRAINT_SCHEMA",
	"CONSTRUCTOR",
	"CONTAINS",
	"CONTINUE",
	"CONVERT",
	"CORR",
	"CORRESPONDING",
	"COUNT",
	"COVAR_POP",
	"COVAR_SAMP",
	"CREATE",
	"CROSS",
	"CUBE",
	"CUME_DIST",
	"CURRENT",
	"CURRENT_CATALOG",
	"CURRENT_DATE",
	"CURRENT_DEFAULT_TRANSFORM_GROUP",
	"CURRENT_PATH",
	"CURRENT_ROLE",
	"CURRENT_SCHEMA",
	"CURRENT_TIME",
	"CURRENT_TIMESTAMP",
	"CURRENT_TRANSFORM_GROUP_FOR_TYPE",
	"CURRENT_USER",
	"CURSOR",
	"CURSOR_NAME",
	"CYCLE",
	"DATA",
	"DATABASE",
	"DATE",
	"DATETIME_INTERVAL_CODE",
	"DATETIME_INTERVAL_PRECISION",
	"DAY",
	"DEALLOCATE",
	"DEC",
	"DECADE",
	"DECIMAL",
	"DECLARE",
	"DEFAULT",
	"DEFAULTS",
	"DEFERRABLE",
	"DEFERRED",
	"DEFINED",
	"DEFINER",
	"DEGREE",
	"DELETE",
	"DENSE_RANK",
	"DEPTH",
	"DEREF",
	"DERIVED",
	"DESC",
	"DESCRIBE",
	"DESCRIPTION",
	"DESCRIPTOR",
	"DETERMINISTIC",
	"DIAGNOSTICS",
	"DISALLOW",
	"DISCONNECT",
	"DISPATCH",
	"DISTINCT",
	"DOMAIN",
	"DOUBLE",
	"DOW",
	"DOY",
	"DROP",
	"DYNAMIC",
	"DYNAMIC_FUNCTION",
	"DYNAMIC_FUNCTION_CODE",
	"EACH",
	"ELEMENT",
	"ELSE",
	"END",
	"END-EXEC",
	"EPOCH",
	"EQUALS",
	"ESCAPE",
	"EVERY",
	"EXCEPT",
	"EXCEPTION",
	"EXCLUDE",
	"EXCLUDING",
	"EXEC",
	"EXECUTE",
	"EXISTS",
	"EXP",
	"EXPLAIN",
	"EXTEND",
	"EXTERNAL",
	"EXTRACT",
	"FALSE",
	"FETCH",
	"FILTER",
	"FINAL",
	"FIRST",
	"FIRST_VALUE",
	"FLOAT",
	"FLOOR",
	"FOLLOWING",
	"FOR",
	"FOREIGN",
	"FORTRAN",
	"FOUND",
	"FRAC_SECOND",
	"FREE",
	"FROM",
	"FULL",
	"FUNCTION",
	"FUSION",
	"G",
	"GENERAL",
	"GENERATED",
	"GET",
	"GLOBAL",
	"GO",
	"GOTO",
	"GRANT",
	"GRANTED",
	"GROUP",
	"GROUPING",
	"HAVING",
	"HIERARCHY",
	"HOLD",
	"HOUR",
	"IDENTITY",
	"IMMEDIATE",
	"IMPLEMENTATION",
	"IMPORT",
	"IN",
	"INCLUDING",
	"INCREMENT",
	"INDICATOR",
	"INITIALLY",
	"INNER",
	"INOUT",
	"INPUT",
	"INSENSITIVE",
	"INSERT",
	"INSTANCE",
	"INSTANTIABLE",
	"INT",
	"INTEGER",
	"INTERSECT",
	"INTERSECTION",
	"INTERVAL",
	"INTO",
	"INVOKER",
	"IS",
	"ISOLATION",
	"JAVA",
	"JOIN",
	"K",
	"KEY",
	"KEY_MEMBER",
	"KEY_TYPE",
	"LABEL",
	"LANGUAGE",
	"LARGE",
	"LAST",
	"LAST_VALUE",
	"LATERAL",
	"LEADING",
	"LEFT",
	"LENGTH",
	"LEVEL",
	"LIBRARY",
	"LIKE",
	"LIMIT",
	"LN",
	"LOCAL",
	"LOCALTIME",
	"LOCALTIMESTAMP",
	"LOCATOR",
	"LOWER",
	"M",
	"MAP",
	"MATCH",
	"MATCHED",
	"MAX",
	"MAXVALUE",
	"MEMBER",
	"MERGE",
	"MESSAGE_LENGTH",
	"MESSAGE_OCTET_LENGTH",
	"MESSAGE_TEXT",
	"METHOD",
	"MICROSECOND",
	"MILLENNIUM",
	"MIN",
	"MINUTE",
	"MINVALUE",
	"MOD",
	"MODIFIES",
	"MODULE",
	"MODULES",
	"MONTH",
	"MORE",
	"MULTISET",
	"MUMPS",
	"NAME",
	"NAMES",
	"NATIONAL",
	"NATURAL",
	"NCHAR",
	"NCLOB",
	"NESTING",
	"NEW",
	"NEXT",
	"NO",
	"NONE",
	"NORMALIZE",
	"NORMALIZED",
	"NOT",
	"NULL",
	"NULLABLE",
	"NULLIF",
	"NULLS",
	"NUMBER",
	"NUMERIC",
	"OBJECT",
	"OCTETS",
	"OCTET_LENGTH",
	"OF",
	"OFFSET",
	"OLD",
	"ON",
	"ONLY",
	"OPEN",
	"OPTION",
	"OPTIONS",
	"OR",
	"ORDER",
	"ORDERING",
	"ORDINALITY",
	"OTHERS",
	"OUT",
	"OUTER",
	"OUTPUT",
	"OVER",
	"OVERLAPS",
	"OVERLAY",
	"OVERRIDING",
	"PAD",
	"PARAMETER",
	"PARAMETER_MODE",
	"PARAMETER_NAME",
	"PARAMETER_ORDINAL_POSITION",
	"PARAMETER_SPECIFIC_CATALOG",
	"PARAMETER_SPECIFIC_NAME",
	"PARAMETER_SPECIFIC_SCHEMA",
	"PARTIAL",
	"PARTITION",
	"PASCAL",
	"PASSTHROUGH",
	"PATH",
	"PERCENTILE_CONT",
	"PERCENTILE_DISC",
	"PERCENT_RANK",
	"PLACING",
	"PLAN",
	"PLI",
	"POSITION",
	"POWER",
	"PRECEDING",
	"PRECISION",
	"PREPARE",
	"PRESERVE",
	"PRIMARY",
	"PRIOR",
	"PRIVILEGES",
	"PROCEDURE",
	"PUBLIC",
	"QUARTER",
	"RANGE",
	"RANK",
	"RAW",
	"READ",
	"READS",
	"REAL",
	"RECURSIVE",
	"REF",
	"REFERENCES",
	"REFERENCING",
	"REGR_AVGX",
	"REGR_AVGY",
	"REGR_COUNT",
	"REGR_INTERCEPT",
	"REGR_R2",
	"REGR_SLOPE",
	"REGR_SXX",
	"REGR_SXY",
	"REGR_SYY",
	"RELATIVE",
	"RELEASE",
	"REPEATABLE",
	"RESET",
	"RESTART",
	"RESTRICT",
	"RESULT",
	"RETURN",
	"RETURNED_CARDINALITY",
	"RETURNED_LENGTH",
	"RETURNED_OCTET_LENGTH",
	"RETURNED_SQLSTATE",
	"RETURNS",
	"REVOKE",
	"RIGHT",
	"ROLE",
	"ROLLBACK",
	"ROLLUP",
	"ROUTINE",
	"ROUTINE_CATALOG",
	"ROUTINE_NAME",
	"ROUTINE_SCHEMA",
	"ROW",
	"ROWS",
	"ROW_COUNT",
	"ROW_NUMBER",
	"SAVEPOINT",
	"SCALE",
	"SCHEMA",
	"SCHEMA_NAME",
	"SCOPE",
	"SCOPE_CATALOGS",
	"SCOPE_NAME",
	"SCOPE_SCHEMA",
	"SCROLL",
	"SEARCH",
	"SECOND",
	"SECTION",
	"SECURITY",
	"SELECT",
	"SELF",
	"SENSITIVE",
	"SEQUENCE",
	"SERIALIZABLE",
	"SERVER",
	"SERVER_NAME",
	"SESSION",
	"SESSION_USER",
	"SET",
	"SETS",
	"SIMILAR",
	"SIMPLE",
	"SIZE",
	"SMALLINT",
	"SOME",
	"SOURCE",
	"SPACE",
	"SPECIFIC",
	"SPECIFICTYPE",
	"SPECIFIC_NAME",
	"SQL",
	"SQLEXCEPTION",
	"SQLSTATE",
	"SQLWARNING",
	"SQL_TSI_DAY",
	"SQL_TSI_FRAC_SECOND",
	"SQL_TSI_HOUR",
	"SQL_TSI_MICROSECOND",
	"SQL_TSI_MINUTE",
	"SQL_TSI_MONTH",
	"SQL_TSI_QUARTER",
	"SQL_TSI_SECOND",
	"SQL_TSI_WEEK",
	"SQL_TSI_YEAR",
	"SQRT",
	"START",
	"STATE",
	"STATEMENT",
	"STATIC",
	"STATISTICS",
	"STDDEV_POP",
	"STDDEV_SAMP",
	"STREAM",
	"STRING",
	"STRUCTURE",
	"STYLE",
	"SUBCLASS_ORIGIN",
	"SUBMULTISET",
	"SUBSTITUTE",
	"SUBSTRING",
	"SUM",
	"SYMMETRIC",
	"SYSTEM",
	"SYSTEM_USER",
	"TABLE",
	"TABLESAMPLE",
	"TABLE_NAME",
	"TEMPORARY",
	"THEN",
	"TIES",
	"TIME",
	"TIMESTAMP",
	"TIMESTAMPADD",
	"TIMESTAMPDIFF",
	"TIMEZONE_HOUR",
	"TIMEZONE_MINUTE",
	"TINYINT",
	"TO",
	"TOP_LEVEL_COUNT",
	"TRAILING",
	"TRANSACTION",
	"TRANSACTIONS_ACTIVE",
	"TRANSACTIONS_COMMITTED",
	"TRANSACTIONS_ROLLED_BACK",
	"TRANSFORM",
	"TRANSFORMS",
	"TRANSLATE",
	"TRANSLATION",
	"TREAT",
	"TRIGGER",
	"TRIGGER_CATALOG",
	"TRIGGER_NAME",
	"TRIGGER_SCHEMA",
	"TRIM",
	"TRUE",
	"TYPE",
	"UESCAPE",
	"UNBOUNDED",
	"UNCOMMITTED",
	"UNDER",
	"UNION",
	"UNIQUE",
	"UNKNOWN",
	"UNNAMED",
	"UNNEST",
	"UPDATE",
	"UPPER",
	"UPSERT",
	"USAGE",
	"USER",
	"USER_DEFINED_TYPE_CATALOG",
	"USER_DEFINED_TYPE_CODE",
	"USER_DEFINED_TYPE_NAME",
	"USER_DEFINED_TYPE_SCHEMA",
	"USING",
	"VALUE",
	"VALUES",
	"VARBINARY",
	"VARCHAR",
	"VARYING",
	"VAR_POP",
	"VAR_SAMP",
	"VERSION",
	"VIEW",
	"WEEK",
	"WHEN",
	"WHENEVER",
	"WHERE",
	"WIDTH_BUCKET",
	"WINDOW",
	"WITH",
	"WITHIN",
	"WITHOUT",
	"WORK",
	"WRAPPER",
	"WRITE",
	"XML",
	"YEAR",
	"ZONE",
)

==> cli-3.48.0.tar.gz: cli-3.48.0/pkg/flink/config/sql_keywords.go <==
package config

import (
	"github.com/confluentinc/cli/v3/pkg/types"
)

var SQLKeywords = types.NewSet(
	"ABS",
	"ACOS",
	"ADD",
	"ADMIN",
	"AFTER",
	"ALL",
	"ALLOW",
	"ALTER",
	"ANALYZE",
	"AND",
	"ANY",
	"ARE",
	"ARRAY",
	"ARRAY_CONTAINS",
	"AS",
	"ASC",
	"ASCII",
	"ASIN",
	"ASYMMETRIC",
	"AT",
	"ATAN",
	"ATAN2",
	"AVG",
	"BEFORE",
	"BEGIN",
	"BETWEEN",
	"BIGINT",
	"BIN",
	"BINARY",
	"BIT",
	"BLOB",
	"BOOLEAN",
	"BOTH",
	"BY",
	"BYTES",
	"CALL",
	"CALLED",
	"CALL_REMOTE_SCALAR",
	"CALL_REMOTE_SCALAR_STR",
	"CARDINALITY",
	"CASCADE",
	"CASCADED",
	"CASE",
	"CAST",
	"CATALOG",
	"CATALOGS",
	"CEIL",
	"CENTURY",
	"CHAIN",
	"CHANGELOG_MODE",
	"CHAR",
	"CHARACTER",
	"CHARACTERS",
	"CHARACTER_LENGTH",
	"CHAR_LENGTH",
	"CHECK",
	"CHR",
	"CLOB",
	"CLOSE",
	"COALESCE",
	"COLLATE",
	"COLLECT",
	"COLUMN",
	"COLUMNS",
	"COMMENT",
	"COMMIT",
	"COMPACT",
	"CONCAT",
	"CONCAT_WS",
	"CONNECT",
	"CONSTRAINT",
	"CONSTRAINTS",
	"CONSTRUCTOR",
	"CONTAINS",
	"CONVERT",
	"CONVERT_TZ",
	"COS",
	"COSH",
	"COT",
	"COUNT",
	"CREATE",
	"CROSS",
	"CUBE",
	"CUME_DIST",
	"CUMULATE",
	"CURRENT",
	"CURRENT_DATABASE",
	"CURRENT_DATE",
	"CURRENT_ROW_TIMESTAMP",
	"CURRENT_TIME",
	"CURRENT_TIMESTAMP",
	"CURRENT_WATERMARK",
	"CURSOR",
	"CYCLE",
	"DATA",
	"DATABASE",
	"DATABASES",
	"DATE",
	"DATETIME",
	"DATE_FORMAT",
	"DAY",
	"DAYOFMONTH",
	"DAYOFWEEK",
	"DAYOFYEAR",
	"DAYS",
	"DEC",
	"DECADE",
	"DECIMAL",
	"DECLARE",
	"DECODE",
	"DEFAULT",
	"DEFINE",
	"DEFINED",
	"DEGREES",
	"DELETE",
	"DENSE_RANK",
	"DESC",
	"DESCRIBE",
	"DESCRIPTOR",
	"DISTINCT",
	"DIV",
	"DOUBLE",
	"DROP",
	"E",
	"EACH",
	"ELEMENT",
	"ELSE",
	"ENCODE",
	"ENCODING",
	"END",
	"ENFORCED",
	"ENGINE",
	"EPOCH",
	"EQUALS",
	"ERROR",
	"ESCAPE",
	"ESTIMATED_COST",
	"EXCEPT",
	"EXCEPTION",
	"EXCLUDE",
	"EXCLUDING",
	"EXECUTE",
	"EXISTS",
	"EXP",
	"EXPLAIN",
	"EXTENDED",
	"EXTERNAL",
	"EXTRACT",
	"FALSE",
	"FILE",
	"FINAL",
	"FIRST",
	"FIRST_VALUE",
	"FLOAT",
	"FLOOR",
	"FOLLOWING",
	"FOR",
	"FORMAT",
	"FORTRAN",
	"FOUND",
	"FRAC_SECOND",
	"FROM",
	"FROM_BASE64",
	"FROM_UNIXTIME",
	"FULL",
	"FUNCTION",
	"FUNCTIONS",
	"GENERAL",
	"GENERATED",
	"GLOBAL",
	"GO",
	"GOTO",
	"GRANT",
	"GRANTED",
	"GREATEST",
	"GROUP",
	"GROUPING",
	"GROUPING_ID",
	"GROUPS",
	"GROUP_ID",
	"HAVING",
	"HEX",
	"HOP",
	"HOUR",
	"HOURS",
	"IF",
	"IFNULL",
	"IGNORE",
	"IMPORT",
	"IN",
	"INCLUDING",
	"INCREMENT",
	"INITCAP",
	"INNER",
	"INOUT",
	"INPUT",
	"INSERT",
	"INSTR",
	"INT",
	"INTEGER",
	"INTERSECT",
	"INTERVAL",
	"INTO",
	"INVOKER",
	"INVOKE_OPENAI",
	"IS",
	"IS_ALPHA",
	"IS_DECIMAL",
	"IS_DIGIT",
	"JAR",
	"JARS",
	"JAVA",
	"JOB",
	"JOBS",
	"JOIN",
	"JSON",
	"JSON_ARRAY",
	"JSON_EXECUTION_PLAN",
	"JSON_EXISTS",
	"JSON_OBJECT",
	"JSON_QUERY",
	"JSON_STRING",
	"JSON_VALUE",
	"KEY",
	"KEY_MEMBER",
	"KEY_TYPE",
	"LABEL",
	"LAG",
	"LANGUAGE",
	"LAST",
	"LAST_VALUE",
	"LATERAL",
	"LEAD",
	"LEADING",
	"LEAST",
	"LEFT",
	"LENGTH",
	"LEVEL",
	"LIKE",
	"LIMIT",
	"LISTAGG",
	"LN",
	"LOAD",
	"LOCAL",
	"LOCALTIME",
	"LOCALTIMESTAMP",
	"LOCATE",
	"LOG",
	"LOG10",
	"LOG2",
	"LOWER",
	"LPAD",
	"LTRIM",
	"MAP",
	"MATCH",
	"MATCH_RECOGNIZE",
	"MATCH_ROWTIME",
	"MAX",
	"MD5",
	"MEASURES",
	"MERGE",
	"METADATA",
	"MICROSECOND",
	"MILLENNIUM",
	"MILLISECOND",
	"MIN",
	"MINUS",
	"MINUTE",
	"MINUTES",
	"MINVALUE",
	"MOD",
	"MODIFIES",
	"MODIFY",
	"MODULE",
	"MODULES",
	"MONTH",
	"MONTHS",
	"MULTISET",
	"NANOSECOND",
	"NATURAL",
	"NEXT",
	"NO",
	"NONE",
	"NOT",
	"NOW",
	"NTILE",
	"NULL",
	"NULLIF",
	"NULLS",
	"NUMBER",
	"NUMERIC",
	"OF",
	"OFFSET",
	"ON",
	"ONE",
	"OPTION",
	"OPTIONS",
	"OR",
	"ORDER",
	"ORDERING",
	"OTLP_EXAMPLE_METRICS",
	"OTLP_METRICS",
	"OUT",
	"OUTER",
	"OUTPUT",
	"OVER",
	"OVERLAPS",
	"OVERLAY",
	"OVERWRITE",
	"OVERWRITING",
	"PARSE_URL",
	"PARTITION",
	"PARTITIONED",
	"PARTITIONS",
	"PASSING",
	"PAST",
	"PATH",
	"PATTERN",
	"PER",
	"PERCENT",
	"PERCENT_RANK",
	"PERIOD",
	"PI",
	"PLACING",
	"PLAN",
	"POSITION",
	"POWER",
	"PRECEDING",
	"PRESERVE",
	"PRIMARY",
	"PRIOR",
	"PRIVILEGES",
	"PROCTIME",
	"PUBLIC",
	"PYTHON",
	"PYTHON_ARCHIVES",
	"PYTHON_DEPENDENCIES",
	"PYTHON_FILES",
	"PYTHON_JAR",
	"PYTHON_PARAMETER",
	"PYTHON_REQUIREMENTS",
	"QUARTER",
	"RADIANS",
	"RAND",
	"RAND_INTEGER",
	"RANGE",
	"RANK",
	"RAW",
	"READ",
	"REGEXP",
	"REGEXP_EXTRACT",
	"REGEXP_REPLACE",
	"RELATIVE",
	"REMOVE",
	"RENAME",
	"REPEAT",
	"REPLACE",
	"RESET",
	"RESPECT",
	"RESTART",
	"RESTRICT",
	"REVERSE",
	"REVOKE",
	"RIGHT",
	"RLIKE",
	"ROLE",
	"ROLLBACK",
	"ROLLUP",
	"ROUND",
	"ROW",
	"ROWS",
	"ROW_COUNT",
	"ROW_NUMBER",
	"RPAD",
	"RTRIM",
	"SCALA",
	"SCALAR",
	"SCALE",
	"SCHEMA",
	"SECOND",
	"SECONDS",
	"SECRET",
	"SECTION",
	"SECURITY",
	"SELECT",
	"SELF",
	"SERVER",
	"SERVER_NAME",
	"SESSION",
	"SET",
	"SETS",
	"SHA1",
	"SHA2",
	"SHA224",
	"SHA256",
	"SHA384",
	"SHA512",
	"SHOW",
	"SIGN",
	"SIMILAR",
	"SIMPLE",
	"SIN",
	"SINH",
	"SIZE",
	"SKIP",
	"SLIDE",
	"SMALLINT",
	"SOURCE",
	"SOURCE_WATERMARK",
	"SPACE",
	"SPLIT_INDEX",
	"SQRT",
	"START",
	"STATE",
	"STATEMENT",
	"STATIC",
	"STDDEV",
	"STDDEV_POP",
	"STDDEV_SAMP",
	"STEP",
	"STRING",
	"STRUCTURE",
	"STR_TO_MAP",
	"STYLE",
	"SUBSTR",
	"SUBSTRING",
	"SUM",
	"SYMMETRIC",
	"SYSTEM",
	"SYSTEM_TIME",
	"SYSTEM_USER",
	"TABLE",
	"TABLES",
	"TABLESAMPLE",
	"TAN",
	"TANH",
	"TEMPORARY",
	"THEN",
	"TIME",
	"TIMECOL",
	"TIMESTAMP",
	"TIMESTAMPADD",
	"TIMESTAMPDIFF",
	"TIMESTAMP_LTZ",
	"TINYINT",
	"TO",
	"TO_BASE64",
	"TO_DATE",
	"TO_TIMESTAMP",
	"TO_TIMESTAMP_LTZ",
	"TRAILING",
	"TRANSFORM",
	"TRIM",
	"TRUE",
	"TRUNCATE",
	"TRY_CAST",
	"TUMBLE",
	"TYPE",
	"TYPEOF",
	"UNBOUNDED",
	"UNDER",
	"UNION",
	"UNIQUE",
	"UNIX_TIMESTAMP",
	"UNKNOWN",
	"UNLOAD",
	"UNNEST",
	"UPPER",
	"UPSERT",
	"USAGE",
	"USE",
	"USER",
	"USING",
	"UTF16",
	"UTF32",
	"UTF8",
	"UUID",
	"VALUE",
	"VALUES",
	"VARBINARY",
	"VARCHAR",
	"VARIANCE",
	"VAR_POP",
	"VAR_SAMP",
	"VERSION",
	"VIEW",
	"VIEWS",
	"VIRTUAL",
	"WATERMARK",
	"WATERMARKS",
	"WEEK",
	"WEEKS",
	"WHEN",
	"WHERE",
	"WINDOW",
	"WITH",
	"WITHIN",
	"WITHOUT",
	"WORK",
	"WRAPPER",
	"YEAR",
	"YEARS",
	"ZONE",
)
